User Manual
===========

Quick Start
-----------

.. code-block:: shell

  pip install toolkit_cmm
  # or test.pypi
  pip install --index-url https://test.pypi.org/simple/ toolkit_cmm

.. code-block:: py

  from toolkit_cmm.helloworld import helloworld
  print(helloworld())
